.. AUTO-GENERATED FILE -- DO NOT EDIT!

eventloop.zmqstream
===================

Module: :mod:`eventloop.zmqstream`
----------------------------------
.. automodule:: zmq.eventloop.zmqstream

.. currentmodule:: zmq.eventloop.zmqstream

:class:`ZMQStream`
------------------


.. autoclass:: ZMQStream
  :members:
  :undoc-members:
  :inherited-members:
